@@ -83,7 +83,7 @@ echo $getpercent % Fresh Swap Written
 banner "$getpercent % Fresh Swap Written
 $getcurrent Mb of $swapsizembytes Mb"
 #If 94% show warning dialog
-if [ $getpercent -ge 94 ]; then
+if [ $getpercent -ge $psb ]; then
 dialog "
 
 ***Fresh Swap Recommended***
